# -*- coding: utf-8; Mode: Python; indent-tabs-mode: nil; tab-width: 4 -*-

# Copyright (C) 2006, 2007, 2008 Canonical Ltd.
# Written by Colin Watson <cjwatson@ubuntu.com>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os
import debconf
import commands

from ubiquity.plugin import *
from ubiquity import i18n
from ubiquity import misc
from ubiquity import auto_update
from ubiquity import osextras

NAME = 'usessetup'
AFTER = 'language'
WEIGHT = 10

class PageBase(PluginUI):
    def radioButtonChanged(self, home):
        """Called when any radio buttons are changed."""
        raise NotImplementedError('radioButtonChanged')

    def setChecked(self, machine):
        """Sets the radio button is checked by name."""
        raise NotImplementedError('setChecked')

    def getChecked(self):
        """Gets the name of radio button is checked."""
        return 'home'

class PageKde(PageBase):
    plugin_breadcrumb = 'ubiquity/text/breadcrumb_uses'

    def __init__(self, controller, *args, **kwargs):
        self.controller = controller
        #if self.controller.oem_user_config:
        #    self.only = True
        #else:
        #    self.only = False

        try:
            from PyQt4 import uic
            from PyQt4.QtGui import QLabel, QWidget

            self.page = uic.loadUi('/usr/share/ubiquity/qt/stepUsesType.ui')

            self.detected = ''
            self.home = self.page.radioButton_home
            self.preg432005 = self.page.radioButton_5
            self.preg382006 = self.page.radioButton
            self.preg452007 = self.page.radioButton_6
            self.preg832008 = self.page.radioButton_7
            self.preg712010 = self.page.radioButton_2
            self.preg512007 = self.page.radioButton_8
            self.preg692008 = self.page.radioButton_3
            self.preg682009 = self.page.radioButton_9
            self.warning = self.page.uses_warning_label

            self.home.setChecked(True)
            self.home.clicked.connect(self.warningVerify)
            self.preg432005.clicked.connect(self.warningVerify)
            self.preg382006.clicked.connect(self.warningVerify)
            self.preg452007.clicked.connect(self.warningVerify)
            self.preg832008.clicked.connect(self.warningVerify)
            self.preg712010.clicked.connect(self.warningVerify)
            self.preg512007.clicked.connect(self.warningVerify)
            self.preg692008.clicked.connect(self.warningVerify)
            self.preg682009.clicked.connect(self.warningVerify)
            self.warning.hide()

            if self.controller.oem_config:
                self.home.setChecked(True)
                self.preg432005.setCheckable(False)
                self.preg382006.setCheckable(False)
                self.preg452007.setCheckable(False)
                self.preg832008.setCheckable(False)
                self.preg712010.setCheckable(False)
                self.preg512007.setCheckable(False)
                self.preg692008.setCheckable(False)
                self.preg682009.setCheckable(False)

        except Exception, e:
            self.debug('Could not create uses type page: %s', e)
            self.page = None

        self.plugin_widgets = self.page

    def setChecked(self, machine):
        if machine == 'home':
            self.home.setChecked(True)
        elif machine == '432005':
            self.preg432005.setChecked(True)
        elif machine == '382006':
            self.preg382006.setChecked(True)
        elif machine == '452007':
            self.preg452007.setChecked(True)
        elif machine == '832008':
            self.preg832008.setChecked(True)
        elif machine == '712010':
            self.preg712010.setChecked(True)
        elif machine == '512007':
            self.preg512007.setChecked(True)
        elif machine == '692008':
            self.preg692008.setChecked(True)
        elif machine == '682008':
            self.preg682009.setChecked(True)
        self.warningVerify()

    def warningVerify(self):
        if self.getChecked() != self.detected:
            self.warning.show()
        else:
            self.warning.hide()

    def getChecked(self):
        if self.home.isChecked():
            return 'home'
        elif self.preg432005.isChecked():
            return '432005'
        elif self.preg382006.isChecked():
            return '382006'
        elif self.preg452007.isChecked():
            return '452007'
        elif self.preg832008.isChecked():
            return '832008'
        elif self.preg712010.isChecked():
            return '712010'
        elif self.preg512007.isChecked():
            return '512007'
        elif self.preg692008.isChecked():
            return '692008'
        elif self.preg682009.isChecked():
            return '682008'

class PageDebconf(PageBase):
    plugin_title = 'ubiquity/text/uses_heading_label'

    def __init__(self, controller, *args, **kwargs):
        self.controller = controller

class PageNoninteractive(PageBase):
    def __init__(self, controller, *args, **kwargs):
        self.controller = controller

class Page(Plugin):
    def prepare(self, unfiltered=False):
        self.db.fset('uses-type/machine', 'seen', 'false')

        self.ui.detected = commands.getoutput(
                '/usr/lib/ubiquity/uses-type/detect-machine execute')
        self.ui.setChecked(self.ui.detected)

        questions = ['^uses-type/machine$']
        environ = {'PATH': '/usr/lib/ubiquity/uses-type:' + os.environ['PATH']}

        return (['/usr/lib/ubiquity/uses-type/uses-type'], questions, environ)

    def run(self, priority, question):
        return Plugin.run(self, priority, question)

    def ok_handler(self):
        self.preseed('uses-type/machine', self.ui.getChecked())

        Plugin.ok_handler(self)

class Install(InstallPlugin):
    def prepare(self, unfiltered=False):
        if 'UBIQUITY_OEM_USER_CONFIG' in os.environ:
            return (['/usr/lib/ubiquity/uses-type/uses-type-apply'], [])
        else:
            return (['/usr/lib/ubiquity/uses-type/uses-type-apply', '/target'], [])

    def install(self, target, progress, *args, **kwargs):
        progress.info('ubiquity/install/usestype')
        return InstallPlugin.install(self, target, progress, *args, **kwargs)
